==> sghi_core-0.2.33.tar.gz: test/afya_moja_core/unit_tests/core/entities/caregiver/managed_client_response_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';

void main() {
  group('ManagedClientsResponse', () {
    testWidgets('fromJson works correctly', (WidgetTester tester) async {
      final ManagedClientsResponse managedClientsResponseFromJson =
          ManagedClientsResponse.fromJson(
        <String, dynamic>{
          'getCaregiverManagedClients': <String, dynamic>{
            'managedClients': <dynamic>[
              <String, dynamic>{
                'caregiverConsent': true,
                'clientConsent': true,
                'workStationDetails': <String, dynamic>{
                  'notifications': 1,
                  'surveys': 1,
                  'articles': 1,
                  'messages': 1
                },
                'clientProfile': <String, dynamic>{
                  'id': '0some-id',
                  'username': 'testUserName',
                  'active': true,
                  'termsAccepted': true,
                }
              },
              <String, dynamic>{
                'caregiverConsent': true,
                'clientConsent': true,
                'workStationDetails': <String, dynamic>{
                  'notifications': 0,
                  'surveys': 0,
                  'articles': 0,
                  'Messages': 0
                },
                'clientProfile': <String, dynamic>{
                  'id': '0some-id',
                  'username': 'testUserName',
                  'active': true,
                  'termsAccepted': true,
                }
              }
            ]
          }
        },
      );

      expect(
        managedClientsResponseFromJson
            .managedClients?.clients?.first.caregiverConsent,
        true,
      );
      expect(
        managedClientsResponseFromJson
            .managedClients?.clients?.first.workStationDetails?.notifications,
        1,
      );
    });
  });
}

==> sghi_core-0.3.56.tar.gz: test/afya_moja_core/unit_tests/core/entities/caregiver/managed_client_response_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';

void main() {
  group('ManagedClientsResponse', () {
    testWidgets('fromJson works correctly', (WidgetTester tester) async {
      final ManagedClientsResponse managedClientsResponseFromJson =
          ManagedClientsResponse.fromJson(
        <String, dynamic>{
          'getCaregiverManagedClients': <String, dynamic>{
            'managedClients': <dynamic>[
              <String, dynamic>{
                'caregiverConsent': 'ACCEPTED',
                'clientConsent': 'ACCEPTED',
                'workStationDetails': <String, dynamic>{
                  'notifications': 1,
                  'surveys': 1,
                  'articles': 1,
                  'messages': 1
                },
                'clientProfile': <String, dynamic>{
                  'id': '0some-id',
                  'user': <String, dynamic>{
                    'id': '0some-id',
                    'username': 'testUserName',
                    'name': 'test Name',
                    'dateOfBirth': '2001-01-01T00:00:00Z',
                    'active': true,
                    'termsAccepted': true,
                  }
                }
              },
              <String, dynamic>{
                'caregiverConsent': 'REJECTED',
                'clientConsent': 'PENDING',
                'workStationDetails': <String, dynamic>{
                  'notifications': 0,
                  'surveys': 0,
                  'articles': 0,
                  'Messages': 0
                },
                'clientProfile': <String, dynamic>{
                  'id': '0some-id',
                  'user': <String, dynamic>{
                    'id': '0some-id',
                    'username': 'testUserName',
                    'name': 'test Name',
                    'dateOfBirth': '2001-01-01T00:00:00Z',
                    'active': true,
                    'termsAccepted': true,
                  }
                }
              }
            ]
          }
        },
      );

      expect(
        managedClientsResponseFromJson
            .managedClients?.clients?.first.caregiverConsent,
        ConsentStatus.ACCEPTED,
      );
      expect(
        managedClientsResponseFromJson
            .managedClients?.clients?.first.workStationDetails?.notifications,
        1,
      );
    });
  });
}
